==> easyviper.extended.behaviours.package.debug-1.0.1-sources.jar: com/ebmwebsourcing/easyviper/core/extended/behaviours/_package/debug/impl/BreakpointBehaviourImpl.java <==
/**
 * easy VIPER software - Copyright (c) 2009 PetalsLink, 
 * http://www.petalslink.com/ 
 *  
 * This library is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU Lesser General Public License as published by the Free 
 * Software Foundation; either version 2.1 of the License, or (at your option) 
 * any later version. This library is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
 * General Public License for more details. 
 *  
 * You should have received a copy of the GNU Lesser General Public License 
 * along with this library; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.impl;

import java.util.List;
import java.util.Map;
import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.annotations.Interface;
import org.objectweb.fractal.fraclet.annotations.Requires;
import org.objectweb.fractal.fraclet.types.Contingency;

import com.ebmwebsourcing.easyviper.core.api.CoreException;
import com.ebmwebsourcing.easyviper.core.api.engine.Execution;
import com.ebmwebsourcing.easyviper.core.api.engine.Node;
import com.ebmwebsourcing.easyviper.core.api.engine.Scope;
import com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.api.BreakpointBehaviour;
import com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.api.DebugBehaviour;
import com.ebmwebsourcing.easyviper.core.service.extended.behaviour.api.AbstractExtendedBehaviourImpl;


/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@org.objectweb.fractal.fraclet.annotations.Component(provides = @Interface(name = "service", signature = BreakpointBehaviour.class))
public class BreakpointBehaviourImpl extends AbstractExtendedBehaviourImpl implements
BreakpointBehaviour {

	private static final long serialVersionUID = 1L;

	private Logger log = Logger.getLogger(BreakpointBehaviourImpl.class
			.getName());

	@Requires(name = "node", contingency = Contingency.OPTIONAL)
	protected Node node;

	public BreakpointBehaviourImpl() {

	}


	public void setInitializationContext(final Map<String, Object> context)
	throws CoreException {
		// do nothing
	}

	@Override
	public void executeActivity() throws CoreException {
		if (this.state == State.ACTIVITY_INACTIVE) {
			this.log.finest("start breakpoint behaviour on node: "
					+ this.node.getName());
			this.state = State.ACTIVITY_STARTED;

			DebugBehaviour debug = findDebugBehaviour(this.getNode().getExecution().getParentScope().getProcess());
			if (debug != null) {
				this.log.finest("is debug mode? "
						+ debug.isActivate());
			} else {
				this.log.finest("is debug mode? false - no debug behaviour found");
			}
			if (debug != null && debug.isActivate()) {
				this.getNode().getExecution().setState(
						Execution.State.SUSPENDED);
				this.log.finest("breakpoint behaviour: suspend the execution "
						+ this.getNode().getExecution().getName() + " => "
						+ this.getNode().getExecution().getState());
				this.getNode().selectDefaultNextTarget();
			}
		}
	}

	private DebugBehaviour findDebugBehaviour(Scope process) throws CoreException {
		DebugBehaviour res = null;
		List<DebugBehaviour> debugs = process.findBehaviours(DebugBehaviour.class);
		if(debugs.size() > 1) {
			throw new CoreException("Impossible to have severals DebugBehaviour on severals node");
		}
		if(debugs.size() == 1) {
			res = debugs.get(0);
		}
		return res;
	}


	@Override
	public String toString() {
		return "BreakpointActivity";
	}

	@Override
	public Node getNode() {
		return this.node;
	}

	@Override
	public void setLog(final Logger logger) {
		super.setLog(logger);
		this.log = logger;
	}

}

==> easyviper.extended.behaviours.package.debug-1.1-sources.jar: com/ebmwebsourcing/easyviper/core/extended/behaviours/_package/debug/impl/BreakpointBehaviourImpl.java <==
/**
 * easy VIPER software - Copyright (c) 2009 PetalsLink, 
 * http://www.petalslink.com/ 
 *  
 * This library is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU Lesser General Public License as published by the Free 
 * Software Foundation; either version 2.1 of the License, or (at your option) 
 * any later version. This library is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
 * General Public License for more details. 
 *  
 * You should have received a copy of the GNU Lesser General Public License 
 * along with this library; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.impl;

import java.util.Map;
import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.annotations.Interface;
import org.objectweb.fractal.fraclet.annotations.Requires;
import org.objectweb.fractal.fraclet.types.Contingency;

import com.ebmwebsourcing.easyviper.core.api.CoreException;
import com.ebmwebsourcing.easyviper.core.api.engine.Execution;
import com.ebmwebsourcing.easyviper.core.api.engine.Node;
import com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.api.BreakpointBehaviour;
import com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.api.DebugBehaviour;
import com.ebmwebsourcing.easyviper.core.extended.behaviours._package.debug.util.DebugUtil;
import com.ebmwebsourcing.easyviper.core.service.extended.behaviour.api.AbstractExtendedBehaviourImpl;


/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@org.objectweb.fractal.fraclet.annotations.Component(provides = @Interface(name = "service", signature = BreakpointBehaviour.class))
public class BreakpointBehaviourImpl extends AbstractExtendedBehaviourImpl implements
BreakpointBehaviour {

	private static final long serialVersionUID = 1L;

	private Logger log = Logger.getLogger(BreakpointBehaviourImpl.class
			.getName());

	@Requires(name = "node", contingency = Contingency.OPTIONAL)
	protected Node node;

	public BreakpointBehaviourImpl() {

	}


	public void setInitializationContext(final Map<String, Object> context)
	throws CoreException {
		// do nothing
	}

	@Override
	public void executeActivity() throws CoreException {
		if (this.state == State.ACTIVITY_INACTIVE) {
			this.log.finest("start breakpoint behaviour on node: "
					+ this.node.getName());
			this.state = State.ACTIVITY_STARTED;

			DebugBehaviour debug = DebugUtil.findDebugBehaviour(this.getNode().getExecution().getParentScope().getProcess());
			if (debug != null) {
				this.log.finest("is debug mode? "
						+ debug.isActivate());
			} else {
				this.log.finest("is debug mode? false - no debug behaviour found");
			}
			if (debug != null && debug.isActivate()) {
				this.getNode().getExecution().setState(
						Execution.State.SUSPENDED);
				this.log.finest("breakpoint behaviour: suspend the execution "
						+ this.getNode().getExecution().getName() + " => "
						+ this.getNode().getExecution().getState());
				this.getNode().selectDefaultNextTarget();
			}
		}
	}

	

	@Override
	public String toString() {
		return "BreakpointActivity";
	}

	@Override
	public Node getNode() {
		return this.node;
	}

	@Override
	public void setLog(final Logger logger) {
		super.setLog(logger);
		this.log = logger;
	}

}
